@@ -6,42 +6,43 @@
 */
 
 #include "fileundomanagertest.h"
+#include "mockcoredelegateextensions.h"
 
-#include <QTest>
-#include <QSignalSpy>
 #include <QDateTime>
 #include <QDir>
 #include <QFileInfo>
-#include <qplatformdefs.h>
+#include <QSignalSpy>
+#include <QTest>
 #include <kio/fileundomanager.h>
+#include <qplatformdefs.h>
 
+#include <KUrlMimeData>
+#include <kio/batchrenamejob.h>
 #include <kio/copyjob.h>
+#include <kio/deletejob.h>
 #include <kio/job.h>
 #include <kio/mkpathjob.h>
-#include <kio/deletejob.h>
 #include <kio/paste.h>
 #include <kio/pastejob.h>
 #include <kio/restorejob.h>
-#include <kio/batchrenamejob.h>
 #include <kioglobal_p.h>
 #include <kprotocolinfo.h>
-#include <KUrlMimeData>
 
-#include <QDebug>
 #include <KConfig>
 #include <KConfigGroup>
+#include <QDebug>
 
 #include <errno.h>
 #include <time.h>
 #ifdef Q_OS_WIN
 #include <sys/utime.h>
 #else
-#include <utime.h>
 #include <sys/time.h>
+#include <utime.h>
 #endif
 
-#include <QClipboard>
 #include <QApplication>
+#include <QClipboard>
 #include <QMimeData>
 
 QTEST_MAIN(FileUndoManagerTest)
@@ -157,45 +158,66 @@ static void createTestDirectory(const QString &path)
 class TestUiInterface : public FileUndoManager::UiInterface
 {
 public:
-    TestUiInterface() : FileUndoManager::UiInterface(), m_nextReplyToConfirmDeletion(true)
+    TestUiInterface()
+        : FileUndoManager::UiInterface()
+        , m_mockAskUserInterface(new MockAskUserInterface)
     {
         setShowProgressInfo(false);
     }
-    void jobError(KIO::Job *job) override {
-        qFatal("%s", qPrintable(job->errorString()));
+    void jobError(KIO::Job *job) override
+    {
+        m_errorCode = job->error();
+        qWarning() << job->errorString();
     }
-    bool copiedFileWasModified(const QUrl &src, const QUrl &dest, const QDateTime &srcTime, const QDateTime &destTime) override {
+    bool copiedFileWasModified(const QUrl &src, const QUrl &dest, const QDateTime &srcTime, const QDateTime &destTime) override
+    {
         Q_UNUSED(src);
         m_dest = dest;
         Q_UNUSED(srcTime);
         Q_UNUSED(destTime);
         return true;
     }
-    bool confirmDeletion(const QList<QUrl> &files) override {
-        m_files = files;
-        return m_nextReplyToConfirmDeletion;
+    bool confirmDeletion(const QList<QUrl> &) override
+    {
+        Q_ASSERT(false); // no longer called
+        return false;
     }
     void setNextReplyToConfirmDeletion(bool b)
     {
         m_nextReplyToConfirmDeletion = b;
     }
-    QList<QUrl> files() const
-    {
-        return m_files;
-    }
     QUrl dest() const
     {
         return m_dest;
     }
+    int errorCode() const
+    {
+        return m_errorCode;
+    }
     void clear()
     {
         m_dest = QUrl();
-        m_files.clear();
+        m_errorCode = 0;
+        m_mockAskUserInterface->clear();
     }
+    MockAskUserInterface *askUserMockInterface() const
+    {
+        return m_mockAskUserInterface.get();
+    }
+    void virtual_hook(int id, void *data) override
+    {
+        if (id == HookGetAskUserActionInterface) {
+            AskUserActionInterface **p = static_cast<AskUserActionInterface **>(data);
+            *p = m_mockAskUserInterface.get();
+            m_mockAskUserInterface->m_deleteResult = m_nextReplyToConfirmDeletion;
+        }
+    }
+
 private:
-    bool m_nextReplyToConfirmDeletion;
     QUrl m_dest;
-    QList<QUrl> m_files;
+    std::unique_ptr<MockAskUserInterface> m_mockAskUserInterface;
+    int m_errorCode = 0;
+    bool m_nextReplyToConfirmDeletion = true;
 };
 
 void FileUndoManagerTest::initTestCase()
@@ -227,7 +249,7 @@ void FileUndoManagerTest::initTestCase()
     QDir().mkpath(destDir());
     QVERIFY(QFileInfo(destDir()).isDir());
 
-    QVERIFY(!FileUndoManager::self()->undoAvailable());
+    QVERIFY(!FileUndoManager::self()->isUndoAvailable());
     m_uiInterface = new TestUiInterface; // owned by FileUndoManager
     FileUndoManager::self()->setUiInterface(m_uiInterface);
 }
@@ -241,17 +263,13 @@ void FileUndoManagerTest::cleanupTestCase()
 void FileUndoManagerTest::doUndo()
 {
     QEventLoop eventLoop;
-    bool ok = connect(FileUndoManager::self(), &FileUndoManager::undoJobFinished,
-                      &eventLoop, &QEventLoop::quit);
-    QVERIFY(ok);
-
+    connect(FileUndoManager::self(), &FileUndoManager::undoJobFinished, &eventLoop, &QEventLoop::quit);
     FileUndoManager::self()->undo();
     eventLoop.exec(QEventLoop::ExcludeUserInputEvents); // wait for undo job to finish
 }
 
 void FileUndoManagerTest::testCopyFiles()
 {
-    qDebug();
     // Initially inspired from JobTest::copyFileToSamePartition()
     const QString destdir = destDir();
     QList<QUrl> lst = sourceList();
@@ -260,13 +278,12 @@ void FileUndoManagerTest::testCopyFiles()
     job->setUiDelegate(nullptr);
     FileUndoManager::self()->recordCopyJob(job);
 
-    QSignalSpy spyUndoAvailable(FileUndoManager::self(), SIGNAL(undoAvailable(bool)));
+    QSignalSpy spyUndoAvailable(FileUndoManager::self(), QOverload<bool>::of(&FileUndoManager::undoAvailable));
     QVERIFY(spyUndoAvailable.isValid());
     QSignalSpy spyTextChanged(FileUndoManager::self(), &FileUndoManager::undoTextChanged);
     QVERIFY(spyTextChanged.isValid());
 
-    bool ok = job->exec();
-    QVERIFY(ok);
+    QVERIFY2(job->exec(), qPrintable(job->errorString()));
 
     QVERIFY(QFile::exists(destFile()));
 #ifndef Q_OS_WIN
@@ -275,28 +292,27 @@ void FileUndoManagerTest::testCopyFiles()
 #endif
 
     // might have to wait for dbus signal here... but this is currently disabled.
-    //QTest::qWait( 20 );
-    QVERIFY(FileUndoManager::self()->undoAvailable());
+    // QTest::qWait( 20 );
+    QVERIFY(FileUndoManager::self()->isUndoAvailable());
     QCOMPARE(spyUndoAvailable.count(), 1);
     QCOMPARE(spyTextChanged.count(), 1);
     m_uiInterface->clear();
 
-    m_uiInterface->setNextReplyToConfirmDeletion(false);   // act like the user didn't confirm
+    m_uiInterface->setNextReplyToConfirmDeletion(false); // act like the user didn't confirm
     FileUndoManager::self()->undo();
-    QCOMPARE(m_uiInterface->files().count(), 1);   // confirmDeletion was called
-    QCOMPARE(m_uiInterface->files().constFirst().toString(), QUrl::fromLocalFile(destFile()).toString());
-    QVERIFY(QFile::exists(destFile()));     // nothing happened yet
+    auto *lastMock = m_uiInterface->askUserMockInterface();
+    QCOMPARE(lastMock->m_askUserDeleteCalled, 1);
+    QVERIFY(QFile::exists(destFile())); // nothing happened yet
 
     // OK, now do it
     m_uiInterface->clear();
     m_uiInterface->setNextReplyToConfirmDeletion(true);
     doUndo();
 
-    QVERIFY(!FileUndoManager::self()->undoAvailable());
-    QVERIFY(spyUndoAvailable.count() >= 2);   // it's in fact 3, due to lock/unlock emitting it as well
+    QVERIFY(!FileUndoManager::self()->isUndoAvailable());
+    QVERIFY(spyUndoAvailable.count() >= 2); // it's in fact 3, due to lock/unlock emitting it as well
     QCOMPARE(spyTextChanged.count(), 2);
-    QCOMPARE(m_uiInterface->files().count(), 1);   // confirmDeletion was called
-    QCOMPARE(m_uiInterface->files().constFirst().toString(), QUrl::fromLocalFile(destFile()).toString());
+    QCOMPARE(m_uiInterface->askUserMockInterface()->m_askUserDeleteCalled, 1);
 
     // Check that undo worked
     QVERIFY(!QFile::exists(destFile()));
@@ -308,7 +324,6 @@ void FileUndoManagerTest::testCopyFiles()
 
 void FileUndoManagerTest::testMoveFiles()
 {
-    qDebug();
     const QString destdir = destDir();
     QList<QUrl> lst = sourceList();
     const QUrl d = QUrl::fromLocalFile(destdir);
@@ -316,10 +331,9 @@ void FileUndoManagerTest::testMoveFiles()
     job->setUiDelegate(nullptr);
     FileUndoManager::self()->recordCopyJob(job);
 
-    bool ok = job->exec();
-    QVERIFY(ok);
+    QVERIFY2(job->exec(), qPrintable(job->errorString()));
 
-    QVERIFY(!QFile::exists(srcFile()));     // the source moved
+    QVERIFY(!QFile::exists(srcFile())); // the source moved
     QVERIFY(QFile::exists(destFile()));
 #ifndef Q_OS_WIN
     QVERIFY(!QFileInfo(srcLink()).isSymLink());
@@ -329,7 +343,7 @@ void FileUndoManagerTest::testMoveFiles()
 
     doUndo();
 
-    QVERIFY(QFile::exists(srcFile()));     // the source is back
+    QVERIFY(QFile::exists(srcFile())); // the source is back
     QVERIFY(!QFile::exists(destFile()));
 #ifndef Q_OS_WIN
     QVERIFY(QFileInfo(srcLink()).isSymLink());
@@ -340,16 +354,16 @@ void FileUndoManagerTest::testMoveFiles()
 void FileUndoManagerTest::testCopyDirectory()
 {
     const QString destdir = destDir();
-    QList<QUrl> lst; lst << QUrl::fromLocalFile(srcSubDir());
+    QList<QUrl> lst;
+    lst << QUrl::fromLocalFile(srcSubDir());
     const QUrl d = QUrl::fromLocalFile(destdir);
     KIO::CopyJob *job = KIO::copy(lst, d, KIO::HideProgressInfo);
     job->setUiDelegate(nullptr);
     FileUndoManager::self()->recordCopyJob(job);
 
-    bool ok = job->exec();
-    QVERIFY(ok);
+    QVERIFY2(job->exec(), qPrintable(job->errorString()));
 
-    checkTestDirectory(srcSubDir());   // src untouched
+    checkTestDirectory(srcSubDir()); // src untouched
     checkTestDirectory(destSubDir());
 
     doUndo();
@@ -358,17 +372,37 @@ void FileUndoManagerTest::testCopyDirectory()
     QVERIFY(!QFile::exists(destSubDir()));
 }
 
+void FileUndoManagerTest::testCopyEmptyDirectory()
+{
+    const QString src = srcSubDir() + "/.emptydir";
+    const QString destEmptyDir = destDir() + "/.emptydir";
+    QDir().mkpath(src);
+    KIO::CopyJob *job = KIO::copy({QUrl::fromLocalFile(src)}, QUrl::fromLocalFile(destEmptyDir), KIO::HideProgressInfo);
+    job->setUiDelegate(nullptr);
+    FileUndoManager::self()->recordCopyJob(job);
+
+    QVERIFY2(job->exec(), qPrintable(job->errorString()));
+
+    QVERIFY(QFileInfo(src).isDir()); // untouched
+    QVERIFY(QFileInfo(destEmptyDir).isDir());
+
+    doUndo();
+
+    QVERIFY(QFileInfo(src).isDir()); // untouched
+    QVERIFY(!QFile::exists(destEmptyDir));
+}
+
 void FileUndoManagerTest::testMoveDirectory()
 {
     const QString destdir = destDir();
-    QList<QUrl> lst; lst << QUrl::fromLocalFile(srcSubDir());
+    QList<QUrl> lst;
+    lst << QUrl::fromLocalFile(srcSubDir());
     const QUrl d = QUrl::fromLocalFile(destdir);
     KIO::CopyJob *job = KIO::move(lst, d, KIO::HideProgressInfo);
     job->setUiDelegate(nullptr);
     FileUndoManager::self()->recordCopyJob(job);
 
-    bool ok = job->exec();
-    QVERIFY(ok);
+    QVERIFY2(job->exec(), qPrintable(job->errorString()));
 
     QVERIFY(!QFile::exists(srcSubDir()));
     checkTestDirectory(destSubDir());
@@ -385,14 +419,13 @@ void FileUndoManagerTest::testRenameFile()
     const QUrl newUrl = QUrl::fromLocalFile(srcFile() + ".new");
     QList<QUrl> lst;
     lst.append(oldUrl);
-    QSignalSpy spyUndoAvailable(FileUndoManager::self(), SIGNAL(undoAvailable(bool)));
+    QSignalSpy spyUndoAvailable(FileUndoManager::self(), QOverload<bool>::of(&FileUndoManager::undoAvailable));
     QVERIFY(spyUndoAvailable.isValid());
     KIO::Job *job = KIO::moveAs(oldUrl, newUrl, KIO::HideProgressInfo);
     job->setUiDelegate(nullptr);
     FileUndoManager::self()->recordJob(FileUndoManager::Rename, lst, newUrl, job);
 
-    bool ok = job->exec();
-    QVERIFY(ok);
+    QVERIFY2(job->exec(), qPrintable(job->errorString()));
 
     QVERIFY(!QFile::exists(srcFile()));
     QVERIFY(QFileInfo(newUrl.toLocalFile()).isFile());
@@ -414,8 +447,7 @@ void FileUndoManagerTest::testRenameDir()
     job->setUiDelegate(nullptr);
     FileUndoManager::self()->recordJob(FileUndoManager::Rename, lst, newUrl, job);
 
-    bool ok = job->exec();
-    QVERIFY(ok);
+    QVERIFY2(job->exec(), qPrintable(job->errorString()));
 
     QVERIFY(!QFile::exists(srcSubDir()));
     QVERIFY(QFileInfo(newUrl.toLocalFile()).isDir());
@@ -443,8 +475,7 @@ void FileUndoManagerTest::testCreateSymlink()
     KIO::CopyJob *job = KIO::link(target, link, KIO::HideProgressInfo);
     job->setUiDelegate(nullptr);
     FileUndoManager::self()->recordCopyJob(job);
-    bool ok = job->exec();
-    QVERIFY(ok);
+    QVERIFY2(job->exec(), qPrintable(job->errorString()));
     QVERIFY(QFile::exists(path));
     QVERIFY(QFileInfo(path).isSymLink());
 
@@ -463,17 +494,15 @@ void FileUndoManagerTest::testCreateDir()
     KIO::SimpleJob *job = KIO::mkdir(url);
     job->setUiDelegate(nullptr);
     FileUndoManager::self()->recordJob(FileUndoManager::Mkdir, QList<QUrl>(), url, job);
-    bool ok = job->exec();
-    QVERIFY(ok);
+    QVERIFY2(job->exec(), qPrintable(job->errorString()));
     QVERIFY(QFile::exists(path));
     QVERIFY(QFileInfo(path).isDir());
 
     m_uiInterface->clear();
-    m_uiInterface->setNextReplyToConfirmDeletion(false);   // act like the user didn't confirm
+    m_uiInterface->setNextReplyToConfirmDeletion(false); // act like the user didn't confirm
     FileUndoManager::self()->undo();
-    QCOMPARE(m_uiInterface->files().count(), 1);   // confirmDeletion was called
-    QCOMPARE(m_uiInterface->files().constFirst().toString(), url.toString());
-    QVERIFY(QFile::exists(path));   // nothing happened yet
+    QCOMPARE(m_uiInterface->askUserMockInterface()->m_askUserDeleteCalled, 1);
+    QVERIFY(QFile::exists(path)); // nothing happened yet
 
     // OK, now do it
     m_uiInterface->clear();
@@ -500,11 +529,8 @@ void FileUndoManagerTest::testMkpath()
     m_uiInterface->setNextReplyToConfirmDeletion(true);
     doUndo();
 
-    QVERIFY(!FileUndoManager::self()->undoAvailable());
-    const auto files = m_uiInterface->files();
-    QCOMPARE(files.count(), 2);   // confirmDeletion was called
-    QCOMPARE(files[0].toLocalFile(), path);
-    QCOMPARE(files[1].toLocalFile(), parent);
+    QVERIFY(!FileUndoManager::self()->isUndoAvailable());
+    QCOMPARE(m_uiInterface->askUserMockInterface()->m_askUserDeleteCalled, 1);
 
     QVERIFY(!QFile::exists(path));
 }
@@ -522,8 +548,7 @@ void FileUndoManagerTest::testTrashFiles()
     job->setUiDelegate(nullptr);
     FileUndoManager::self()->recordJob(FileUndoManager::Trash, lst, QUrl(QStringLiteral("trash:/")), job);
 
-    bool ok = job->exec();
-    QVERIFY(ok);
+    QVERIFY2(job->exec(), qPrintable(job->errorString()));
 
     // Check that things got removed
     QVERIFY(!QFile::exists(srcFile()));
@@ -571,8 +596,6 @@ void FileUndoManagerTest::testRestoreTrashedFiles()
         trashUrls.append(QUrl(it.value()));
     }
 
-    qDebug() << trashUrls;
-
     // Restore from trash
     KIO::RestoreJob *restoreJob = KIO::restoreFromTrash(trashUrls, KIO::HideProgressInfo);
     restoreJob->setUiDelegate(nullptr);
@@ -607,19 +630,18 @@ void FileUndoManagerTest::testModifyFileBeforeUndo()
 {
     // based on testCopyDirectory (so that we check that it works for files in subdirs too)
     const QString destdir = destDir();
-    const QList<QUrl> lst{ QUrl::fromLocalFile(srcSubDir()) };
+    const QList<QUrl> lst{QUrl::fromLocalFile(srcSubDir())};
     const QUrl dest = QUrl::fromLocalFile(destdir);
     KIO::CopyJob *job = KIO::copy(lst, dest, KIO::HideProgressInfo);
     job->setUiDelegate(nullptr);
     FileUndoManager::self()->recordCopyJob(job);
 
-    bool ok = job->exec();
-    QVERIFY(ok);
+    QVERIFY2(job->exec(), qPrintable(job->errorString()));
 
-    checkTestDirectory(srcSubDir());   // src untouched
+    checkTestDirectory(srcSubDir()); // src untouched
     checkTestDirectory(destSubDir());
     const QString destFile = destSubDir() + "/fileindir";
-    setTimeStamp(destFile);   // simulate a modification of the file
+    setTimeStamp(destFile); // simulate a modification of the file
 
     doUndo();
 
@@ -719,14 +741,33 @@ void FileUndoManagerTest::testUndoCopyOfDeletedFile()
         QVERIFY(!QFileInfo::exists(dest.toLocalFile()));
     }
 
-    QVERIFY(FileUndoManager::self()->undoAvailable());
-    QSignalSpy spyUndoAvailable(FileUndoManager::self(), static_cast<void (FileUndoManager::*)(bool)>(&FileUndoManager::undoAvailable));
+    QVERIFY(FileUndoManager::self()->isUndoAvailable());
+    QSignalSpy spyUndoAvailable(FileUndoManager::self(), QOverload<bool>::of(&FileUndoManager::undoAvailable));
     QVERIFY(spyUndoAvailable.isValid());
-    // We can't use doUndo() because there is no UndoJob, so the nested event loop would never quit.
-    FileUndoManager::self()->undo();
-    QCOMPARE(spyUndoAvailable.count(), 1);
+    doUndo();
+    QVERIFY(spyUndoAvailable.count() >= 2); // it's in fact 3, due to lock/unlock emitting it as well
     QVERIFY(!spyUndoAvailable.at(0).at(0).toBool());
-    QVERIFY(!FileUndoManager::self()->undoAvailable());
+    QVERIFY(!FileUndoManager::self()->isUndoAvailable());
+}
+
+void FileUndoManagerTest::testErrorDuringMoveUndo()
+{
+    const QString destdir = destDir();
+    QList<QUrl> lst{QUrl::fromLocalFile(srcFile())};
+    KIO::CopyJob *job = KIO::move(lst, QUrl::fromLocalFile(destdir), KIO::HideProgressInfo);
+    job->setUiDelegate(nullptr);
+    FileUndoManager::self()->recordCopyJob(job);
+
+    QVERIFY2(job->exec(), qPrintable(job->errorString()));
+
+    QVERIFY(!QFile::exists(srcFile())); // the source moved
+    QVERIFY(QFile::exists(destFile()));
+    createTestFile(srcFile(), "I'm back");
+
+    doUndo();
+
+    QCOMPARE(m_uiInterface->errorCode(), KIO::ERR_FILE_ALREADY_EXIST);
+    QVERIFY(QFile::exists(destFile())); // still there
 }
 
 // TODO: add test (and fix bug) for  DND of remote urls / "Link here" (creates .desktop files) // Undo (doesn't do anything)
