@@ -11,21 +11,35 @@
 
 QTEST_MAIN(KDirListerTest)
 
-#include <QDebug>
 #include "kiotesthelper.h"
-#include <kio/deletejob.h>
 #include <KDirWatch>
-#include <kprotocolinfo.h>
-#include <kio/job.h>
+#include <QDebug>
 #include <kio/copyjob.h>
+#include <kio/deletejob.h>
+#include <kio/job.h>
+#include <kprotocolinfo.h>
 
 #define WORKAROUND_BROKEN_INOTIFY 0
 
+void MyDirLister::setErrorExpected()
+{
+    m_errorExpected = true;
+}
+
+int MyDirLister::errorCode() const
+{
+    return m_errorCode;
+}
+
 void MyDirLister::handleError(KIO::Job *job)
 {
-    // Currently we don't expect any errors.
-    qCritical() << "KDirLister called handleError!" << job << job->error() << job->errorString();
-    qFatal("aborting");
+    if (!m_errorExpected) {
+        qCritical() << "KDirLister called handleError!" << job << job->error() << job->errorString();
+        qFatal("aborting");
+    } else {
+        m_errorCode = job->error();
+        m_errorExpected = false;
+    }
 }
 
 void KDirListerTest::initTestCase()
@@ -40,7 +54,7 @@ void KDirListerTest::initTestCase()
 
     m_exitCount = 1;
 
-    s_referenceTimeStamp = QDateTime::currentDateTime().addSecs(-120);   // 2 minutes ago
+    s_referenceTimeStamp = QDateTime::currentDateTime().addSecs(-120); // 2 minutes ago
 
     // Create test data:
     /*
@@ -59,7 +73,7 @@ void KDirListerTest::initTestCase()
     createTestDirectory(path + "subdir");
     createTestDirectory(path + "subdir/subsubdir");
 
-    qRegisterMetaType<QList<QPair<KFileItem, KFileItem> > >();
+    qRegisterMetaType<QList<QPair<KFileItem, KFileItem>>>();
 }
 
 void KDirListerTest::cleanup()
@@ -68,6 +82,26 @@ void KDirListerTest::cleanup()
     disconnect(&m_dirLister, nullptr, this, nullptr);
 }
 
+void KDirListerTest::testInvalidUrl()
+{
+    m_dirLister.setErrorExpected();
+    m_dirLister.openUrl(QUrl(":/"), KDirLister::NoFlags);
+    QCOMPARE(m_dirLister.spyStarted.count(), 1);
+    QTRY_COMPARE(m_dirLister.errorCode(), KIO::ERR_MALFORMED_URL);
+    QCOMPARE(m_dirLister.spyCompleted.count(), 0);
+    QVERIFY(m_dirLister.isFinished());
+}
+
+void KDirListerTest::testNonListableUrl()
+{
+    m_dirLister.setErrorExpected();
+    m_dirLister.openUrl(QUrl("data:foo"), KDirLister::NoFlags);
+    QCOMPARE(m_dirLister.spyStarted.count(), 1);
+    QTRY_COMPARE(m_dirLister.errorCode(), KIO::ERR_UNSUPPORTED_ACTION);
+    QCOMPARE(m_dirLister.spyCompleted.count(), 0);
+    QVERIFY(m_dirLister.isFinished());
+}
+
 void KDirListerTest::testOpenUrl()
 {
     m_items.clear();
@@ -82,7 +116,12 @@ void KDirListerTest::testOpenUrl()
     QCOMPARE(m_dirLister.spyCanceled.count(), 0);
     QCOMPARE(m_dirLister.spyCanceledQUrl.count(), 0);
     QCOMPARE(m_dirLister.spyClear.count(), 1);
+
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
     QCOMPARE(m_dirLister.spyClearQUrl.count(), 0);
+#endif
+    QCOMPARE(m_dirLister.spyClearDir.count(), 0);
+
     QCOMPARE(m_dirLister.spyRedirection.count(), 0);
     QCOMPARE(m_items.count(), 0);
     QVERIFY(!m_dirLister.isFinished());
@@ -95,10 +134,15 @@ void KDirListerTest::testOpenUrl()
     QCOMPARE(m_dirLister.spyCanceled.count(), 0);
     QCOMPARE(m_dirLister.spyCanceledQUrl.count(), 0);
     QCOMPARE(m_dirLister.spyClear.count(), 1);
+
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
     QCOMPARE(m_dirLister.spyClearQUrl.count(), 0);
+#endif
+    QCOMPARE(m_dirLister.spyClearDir.count(), 0);
+
     QCOMPARE(m_dirLister.spyRedirection.count(), 0);
-    //qDebug() << m_items;
-    //qDebug() << "In dir" << QDir(path).entryList( QDir::AllEntries | QDir::NoDotAndDotDot);
+    // qDebug() << m_items;
+    // qDebug() << "In dir" << QDir(path).entryList( QDir::AllEntries | QDir::NoDotAndDotDot);
     QCOMPARE(m_items.count(), fileCount());
     QVERIFY(m_dirLister.isFinished());
     disconnect(&m_dirLister, nullptr, this, nullptr);
@@ -145,7 +189,12 @@ void KDirListerTest::testOpenUrlFromCache()
         QCOMPARE(secondDirLister.spyCanceled.count(), 0);
         QCOMPARE(secondDirLister.spyCanceledQUrl.count(), 0);
         QCOMPARE(secondDirLister.spyClear.count(), 1);
+
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
         QCOMPARE(secondDirLister.spyClearQUrl.count(), 0);
+#endif
+        QCOMPARE(secondDirLister.spyClearDir.count(), 0);
+
         QCOMPARE(m_items.count(), 0);
         QVERIFY(!secondDirLister.isFinished());
 
@@ -157,7 +206,12 @@ void KDirListerTest::testOpenUrlFromCache()
         QCOMPARE(secondDirLister.spyCanceled.count(), 0);
         QCOMPARE(secondDirLister.spyCanceledQUrl.count(), 0);
         QCOMPARE(secondDirLister.spyClear.count(), 1);
+
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
         QCOMPARE(secondDirLister.spyClearQUrl.count(), 0);
+#endif
+        QCOMPARE(secondDirLister.spyClearDir.count(), 0);
+
         QCOMPARE(m_items.count(), 4);
         QVERIFY(secondDirLister.isFinished());
     }
@@ -185,7 +239,11 @@ void KDirListerTest::testNewItem()
     QCOMPARE(m_dirLister.spyCanceled.count(), 0);
     QCOMPARE(m_dirLister.spyCanceledQUrl.count(), 0);
     QCOMPARE(m_dirLister.spyClear.count(), 0);
+
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
     QCOMPARE(m_dirLister.spyClearQUrl.count(), 0);
+#endif
+    QCOMPARE(m_dirLister.spyClearDir.count(), 0);
 
     const QUrl itemUrl = QUrl::fromLocalFile(path + fileName);
     KFileItem itemForUrl = KDirLister::cachedItemForUrl(itemUrl);
@@ -195,7 +253,6 @@ void KDirListerTest::testNewItem()
     disconnect(&m_dirLister, nullptr, this, nullptr);
 }
 
-
 // This test assumes testNewItem was run before. So m_dirLister is holding the items already.
 // This test creates 100 more files in the temporary directory in reverse order
 void KDirListerTest::testNewItems()
@@ -225,7 +282,11 @@ void KDirListerTest::testNewItems()
     QCOMPARE(m_dirLister.spyCanceled.count(), 0);
     QCOMPARE(m_dirLister.spyCanceledQUrl.count(), 0);
     QCOMPARE(m_dirLister.spyClear.count(), 0);
+
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
     QCOMPARE(m_dirLister.spyClearQUrl.count(), 0);
+#endif
+    QCOMPARE(m_dirLister.spyClearDir.count(), 0);
 
     const QUrl itemUrl = QUrl::fromLocalFile(path + fileName);
     KFileItem itemForUrl = KDirLister::cachedItemForUrl(itemUrl);
@@ -271,7 +332,11 @@ void KDirListerTest::testNewItemByCopy()
     QCOMPARE(m_dirLister.spyCanceled.count(), 0);
     QCOMPARE(m_dirLister.spyCanceledQUrl.count(), 0);
     QCOMPARE(m_dirLister.spyClear.count(), 0);
+
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
     QCOMPARE(m_dirLister.spyClearQUrl.count(), 0);
+#endif
+    QCOMPARE(m_dirLister.spyClearDir.count(), 0);
 
     // Give some time to KDirWatch
     QTest::qWait(1000);
@@ -293,8 +358,8 @@ void KDirListerTest::testNewItemsInSymlink() // #213799
     tempFile.close();
     const bool symlinkOk = KIOPrivate::createSymlink(path, symPath);
     if (!symlinkOk) {
-        const QString error = QString::fromLatin1("Failed to create symlink '%1' pointing to '%2': %3")
-            .arg(symPath, path, QString::fromLocal8Bit(strerror(errno)));
+        const QString error =
+            QString::fromLatin1("Failed to create symlink '%1' pointing to '%2': %3").arg(symPath, path, QString::fromLocal8Bit(strerror(errno)));
         QVERIFY2(symlinkOk, qPrintable(error));
     }
     MyDirLister dirLister2;
@@ -375,7 +440,12 @@ void KDirListerTest::testRefreshItems()
     QCOMPARE(m_dirLister.spyCanceled.count(), 0);
     QCOMPARE(m_dirLister.spyCanceledQUrl.count(), 0);
     QCOMPARE(m_dirLister.spyClear.count(), 0);
+
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
     QCOMPARE(m_dirLister.spyClearQUrl.count(), 0);
+#endif
+    QCOMPARE(m_dirLister.spyClearDir.count(), 0);
+
     QCOMPARE(m_refreshedItems.count(), 1);
     QPair<KFileItem, KFileItem> entry = m_refreshedItems.first();
     QCOMPARE(entry.first.url().toLocalFile(), fileName);
@@ -423,7 +493,12 @@ void KDirListerTest::testRefreshRootItem()
     QCOMPARE(m_dirLister.spyCanceled.count(), 0);
     QCOMPARE(m_dirLister.spyCanceledQUrl.count(), 0);
     QCOMPARE(m_dirLister.spyClear.count(), 0);
+
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
     QCOMPARE(m_dirLister.spyClearQUrl.count(), 0);
+#endif
+    QCOMPARE(m_dirLister.spyClearDir.count(), 0);
+
     QCOMPARE(m_refreshedItems.count(), 1);
     QPair<KFileItem, KFileItem> entry = m_refreshedItems.first();
     QCOMPARE(entry.first.url().toLocalFile(), path);
@@ -471,7 +546,7 @@ void KDirListerTest::testDeleteItem()
     QCOMPARE(fileCount(), origItemCount);
     const QString path = m_tempDir.path() + '/';
 
-    //qDebug() << "Removing " << path+"toplevelfile_new";
+    // qDebug() << "Removing " << path+"toplevelfile_new";
     QFile::remove(path + QString("toplevelfile_new"));
     // the remove() doesn't always trigger kdirwatch in stat mode, if this all happens in the same second
     KDirWatch::self()->setDirty(path);
@@ -492,7 +567,6 @@ void KDirListerTest::testDeleteItem()
     QCOMPARE(fileCount(), m_items.count());
 }
 
-
 void KDirListerTest::testDeleteItems()
 {
     testOpenUrl(); // ensure m_items is uptodate
@@ -502,7 +576,7 @@ void KDirListerTest::testDeleteItems()
     const QString path = m_tempDir.path() + '/';
 
     qDebug() << "Removing 100 files from " << path;
-    for (int i=0; i <= 100; ++i) {
+    for (int i = 0; i <= 100; ++i) {
         QFile::remove(path + QString("toplevelfile_new_%1").arg(i));
     }
     // the remove() doesn't always trigger kdirwatch in stat mode, if this all happens in the same second
@@ -522,7 +596,6 @@ void KDirListerTest::testDeleteItems()
     QCOMPARE(fileCount(), m_items.count());
 }
 
-
 void KDirListerTest::testRenameItem()
 {
     m_refreshedItems2.clear();
@@ -578,7 +651,7 @@ void KDirListerTest::testRenameAndOverwrite() // has to be run after testRenameI
     QVERIFY(ok);
 
     if (m_refreshedItems.isEmpty()) {
-        QTRY_VERIFY(!m_refreshedItems.isEmpty());  // could come from KDirWatch or KDirNotify.
+        QTRY_VERIFY(!m_refreshedItems.isEmpty()); // could come from KDirWatch or KDirNotify.
     }
 
     // Check that itemsDeleted was emitted -- preferably BEFORE refreshItems,
@@ -627,7 +700,12 @@ void KDirListerTest::testConcurrentListing()
     QCOMPARE(m_dirLister.spyCanceled.count(), 0);
     QCOMPARE(m_dirLister.spyCanceledQUrl.count(), 0);
     QCOMPARE(m_dirLister.spyClear.count(), 1);
+
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
     QCOMPARE(m_dirLister.spyClearQUrl.count(), 0);
+#endif
+    QCOMPARE(m_dirLister.spyClearDir.count(), 0);
+
     QCOMPARE(m_items.count(), 0);
 
     QCOMPARE(dirLister2.spyStarted.count(), 1);
@@ -636,7 +714,12 @@ void KDirListerTest::testConcurrentListing()
     QCOMPARE(dirLister2.spyCanceled.count(), 0);
     QCOMPARE(dirLister2.spyCanceledQUrl.count(), 0);
     QCOMPARE(dirLister2.spyClear.count(), 1);
+
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
     QCOMPARE(dirLister2.spyClearQUrl.count(), 0);
+#endif
+    QCOMPARE(dirLister2.spyClearDir.count(), 0);
+
     QCOMPARE(m_items2.count(), 0);
     QVERIFY(!m_dirLister.isFinished());
     QVERIFY(!dirLister2.isFinished());
@@ -644,13 +727,18 @@ void KDirListerTest::testConcurrentListing()
     // then wait for completed
     qDebug("waiting for completed");
 
-    //QCOMPARE(m_dirLister.spyStarted.count(), 1); // 2 when subdir is already in cache.
+    // QCOMPARE(m_dirLister.spyStarted.count(), 1); // 2 when subdir is already in cache.
     QTRY_COMPARE(m_dirLister.spyCompleted.count(), 1);
     QCOMPARE(m_dirLister.spyCompletedQUrl.count(), 1);
     QCOMPARE(m_dirLister.spyCanceled.count(), 0);
     QCOMPARE(m_dirLister.spyCanceledQUrl.count(), 0);
     QCOMPARE(m_dirLister.spyClear.count(), 1);
+
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
     QCOMPARE(m_dirLister.spyClearQUrl.count(), 0);
+#endif
+    QCOMPARE(m_dirLister.spyClearDir.count(), 0);
+
     QCOMPARE(m_items.count(), 3);
 
     QTRY_COMPARE(dirLister2.spyStarted.count(), 1);
@@ -659,7 +747,12 @@ void KDirListerTest::testConcurrentListing()
     QCOMPARE(dirLister2.spyCanceled.count(), 0);
     QCOMPARE(dirLister2.spyCanceledQUrl.count(), 0);
     QCOMPARE(dirLister2.spyClear.count(), 1);
+
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
     QCOMPARE(dirLister2.spyClearQUrl.count(), 0);
+#endif
+    QCOMPARE(dirLister2.spyClearDir.count(), 0);
+
     QCOMPARE(m_items2.count(), origItemCount);
     if (!m_dirLister.isFinished()) { // false when an update is running because subdir is already in cache
         // TODO check why this fails QVERIFY(m_dirLister.spyCanceled.wait(1000));
@@ -707,7 +800,12 @@ void KDirListerTest::testConcurrentHoldingListing()
     QCOMPARE(dirLister2.spyCanceled.count(), 0);
     QCOMPARE(dirLister2.spyCanceledQUrl.count(), 0);
     QCOMPARE(dirLister2.spyClear.count(), 1);
+
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
     QCOMPARE(dirLister2.spyClearQUrl.count(), 0);
+#endif
+    QCOMPARE(dirLister2.spyClearDir.count(), 0);
+
     QCOMPARE(m_items2.count(), origItemCount);
 
     QTRY_COMPARE(m_dirLister.spyStarted.count(), 1);
@@ -716,7 +814,12 @@ void KDirListerTest::testConcurrentHoldingListing()
     QCOMPARE(m_dirLister.spyCanceled.count(), 0);
     QCOMPARE(m_dirLister.spyCanceledQUrl.count(), 0);
     QCOMPARE(m_dirLister.spyClear.count(), 1);
+
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
     QCOMPARE(m_dirLister.spyClearQUrl.count(), 0);
+#endif
+    QCOMPARE(m_dirLister.spyClearDir.count(), 0);
+
     QVERIFY(dirLister2.isFinished());
     QVERIFY(m_dirLister.isFinished());
     disconnect(&m_dirLister, nullptr, this, nullptr);
@@ -743,7 +846,7 @@ void KDirListerTest::testConcurrentListingAndStop()
     // Before m_dirLister has time to emit the items, let's make dirLister2 call stop().
     // This should not stop the list job for m_dirLister (#267709).
     dirLister2.openUrl(QUrl::fromLocalFile(path), KDirLister::Reload);
-    m_dirLister.openUrl(QUrl::fromLocalFile(path)/*, KDirLister::Reload*/);
+    m_dirLister.openUrl(QUrl::fromLocalFile(path) /*, KDirLister::Reload*/);
 
     QCOMPARE(m_dirLister.spyStarted.count(), 1);
     QCOMPARE(m_dirLister.spyCompleted.count(), 0);
@@ -751,7 +854,12 @@ void KDirListerTest::testConcurrentListingAndStop()
     QCOMPARE(m_dirLister.spyCanceled.count(), 0);
     QCOMPARE(m_dirLister.spyCanceledQUrl.count(), 0);
     QCOMPARE(m_dirLister.spyClear.count(), 1);
+
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
     QCOMPARE(m_dirLister.spyClearQUrl.count(), 0);
+#endif
+    QCOMPARE(m_dirLister.spyClearDir.count(), 0);
+
     QCOMPARE(m_items.count(), 0);
 
     QCOMPARE(dirLister2.spyStarted.count(), 1);
@@ -760,7 +868,12 @@ void KDirListerTest::testConcurrentListingAndStop()
     QCOMPARE(dirLister2.spyCanceled.count(), 0);
     QCOMPARE(dirLister2.spyCanceledQUrl.count(), 0);
     QCOMPARE(dirLister2.spyClear.count(), 1);
+
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
     QCOMPARE(dirLister2.spyClearQUrl.count(), 0);
+#endif
+    QCOMPARE(dirLister2.spyClearDir.count(), 0);
+
     QCOMPARE(m_items2.count(), 0);
     QVERIFY(!m_dirLister.isFinished());
     QVERIFY(!dirLister2.isFinished());
@@ -773,7 +886,12 @@ void KDirListerTest::testConcurrentListingAndStop()
     QCOMPARE(dirLister2.spyCanceled.count(), 1);
     QCOMPARE(dirLister2.spyCanceledQUrl.count(), 1);
     QCOMPARE(dirLister2.spyClear.count(), 1);
+
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
     QCOMPARE(dirLister2.spyClearQUrl.count(), 0);
+#endif
+    QCOMPARE(dirLister2.spyClearDir.count(), 0);
+
     QCOMPARE(m_items2.count(), 0);
 
     // then wait for completed
@@ -782,13 +900,17 @@ void KDirListerTest::testConcurrentListingAndStop()
     QTRY_COMPARE(m_items2.count(), 0);
     QTRY_VERIFY(m_dirLister.isFinished());
 
-    //QCOMPARE(m_dirLister.spyStarted.count(), 1); // 2 when in cache
+    // QCOMPARE(m_dirLister.spyStarted.count(), 1); // 2 when in cache
     QCOMPARE(m_dirLister.spyCompleted.count(), 1);
     QCOMPARE(m_dirLister.spyCompletedQUrl.count(), 1);
     QCOMPARE(m_dirLister.spyCanceled.count(), 0);
     QCOMPARE(m_dirLister.spyCanceledQUrl.count(), 0);
     QCOMPARE(m_dirLister.spyClear.count(), 1);
+
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
     QCOMPARE(m_dirLister.spyClearQUrl.count(), 0);
+#endif
+    QCOMPARE(m_dirLister.spyClearDir.count(), 0);
 
     disconnect(&m_dirLister, nullptr, this, nullptr);
 }
@@ -799,7 +921,7 @@ void KDirListerTest::testDeleteListerEarly()
     testOpenUrl();
 
     // Start a second lister, it will get a cached items job, but delete it before the job can run
-    //qDebug() << "==========================================";
+    // qDebug() << "==========================================";
     {
         m_items.clear();
         const QString path = m_tempDir.path() + '/';
@@ -807,7 +929,7 @@ void KDirListerTest::testDeleteListerEarly()
         secondDirLister.openUrl(QUrl::fromLocalFile(path), KDirLister::NoFlags);
         QVERIFY(!secondDirLister.isFinished());
     }
-    //qDebug() << "==========================================";
+    // qDebug() << "==========================================";
 
     // Check if we didn't keep the deleted dirlister in one of our lists.
     // I guess the best way to do that is to just list the same dir again.
@@ -837,7 +959,12 @@ void KDirListerTest::testOpenUrlTwice()
     QCOMPARE(secondDirLister.spyCanceled.count(), 0); // should not be emitted, see next test
     QCOMPARE(secondDirLister.spyCanceledQUrl.count(), 0);
     QCOMPARE(secondDirLister.spyClear.count(), 2);
+
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
     QCOMPARE(secondDirLister.spyClearQUrl.count(), 0);
+#endif
+    QCOMPARE(secondDirLister.spyClearDir.count(), 0);
+
     if (origItemCount) { // 0 if running this test separately
         QCOMPARE(m_items.count(), origItemCount);
     }
@@ -874,7 +1001,12 @@ void KDirListerTest::testOpenUrlTwiceWithKeep()
     QCOMPARE(secondDirLister.spyCanceled.count(), 0); // should not be emitted, it led to recursion
     QCOMPARE(secondDirLister.spyCanceledQUrl.count(), 0);
     QCOMPARE(secondDirLister.spyClear.count(), 1);
+
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
     QCOMPARE(secondDirLister.spyClearQUrl.count(), 1);
+#endif
+    QCOMPARE(secondDirLister.spyClearDir.count(), 1);
+
     QCOMPARE(m_items.count(), 0);
     QVERIFY(secondDirLister.isFinished());
     disconnect(&secondDirLister, nullptr, this, nullptr);
@@ -898,7 +1030,12 @@ void KDirListerTest::testOpenAndStop()
     QCOMPARE(m_dirLister.spyCanceled.count(), 1);
     QCOMPARE(m_dirLister.spyCanceledQUrl.count(), 1);
     QCOMPARE(m_dirLister.spyClear.count(), 1);
+
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
     QCOMPARE(m_dirLister.spyClearQUrl.count(), 0);
+#endif
+    QCOMPARE(m_dirLister.spyClearDir.count(), 0);
+
     QCOMPARE(m_items.count(), 0); // we had time to stop before the job even started
     QVERIFY(m_dirLister.isFinished());
     disconnect(&m_dirLister, nullptr, this, nullptr);
@@ -917,7 +1054,7 @@ void KDirListerTest::testBug211472()
     connect(&dirLister, &KCoreDirLister::newItems, this, &KDirListerTest::slotNewItems);
 
     dirLister.openUrl(QUrl::fromLocalFile(path));
-    QSignalSpy spyCompleted(&dirLister, SIGNAL(completed()));
+    QSignalSpy spyCompleted(&dirLister, QOverload<>::of(&KCoreDirLister::completed));
     QVERIFY(spyCompleted.wait(1000));
     QVERIFY(dirLister.isFinished());
     QVERIFY(m_items.isEmpty());
@@ -960,7 +1097,7 @@ void KDirListerTest::testBug211472()
     QTRY_COMPARE(m_items.count(), 1);
 
     newDir.remove();
-    QSignalSpy spyClear(&dirLister, SIGNAL(clear()));
+    QSignalSpy spyClear(&dirLister, QOverload<>::of(&KCoreDirLister::clear));
     QVERIFY(spyClear.wait(1000));
 }
 
@@ -974,7 +1111,7 @@ void KDirListerTest::testRenameCurrentDir() // #294445
     connect(&secondDirLister, &KCoreDirLister::newItems, this, &KDirListerTest::slotNewItems);
 
     secondDirLister.openUrl(QUrl::fromLocalFile(path));
-    QSignalSpy spyCompleted(&secondDirLister, SIGNAL(completed()));
+    QSignalSpy spyCompleted(&secondDirLister, QOverload<>::of(&KCoreDirLister::completed));
     QVERIFY(spyCompleted.wait(1000));
     QVERIFY(secondDirLister.isFinished());
     QVERIFY(m_items.empty());
@@ -983,7 +1120,7 @@ void KDirListerTest::testRenameCurrentDir() // #294445
     const QString newPath = m_tempDir.path() + "/newsubdir-2";
     QVERIFY(QDir().rename(path, newPath));
     org::kde::KDirNotify::emitFileRenamed(QUrl::fromLocalFile(path), QUrl::fromLocalFile(newPath));
-    QSignalSpy spyRedirection(&secondDirLister, SIGNAL(redirection(QUrl,QUrl)));
+    QSignalSpy spyRedirection(&secondDirLister, QOverload<const QUrl &, const QUrl &>::of(&KCoreDirLister::redirection));
     QVERIFY(spyRedirection.wait(1000));
 
     // Check that the URL of the root item got updated
@@ -998,9 +1135,9 @@ void KDirListerTest::slotOpenUrlOnRename(const QUrl &newUrl)
     QVERIFY(m_dirLister.openUrl(newUrl));
 }
 
-//This tests for a crash if you connect redirects to openUrl, due
-//to internal data being inconsistently exposed.
-//Matches usage in gwenview.
+// This tests for a crash if you connect redirects to openUrl, due
+// to internal data being inconsistently exposed.
+// Matches usage in gwenview.
 void KDirListerTest::testRenameCurrentDirOpenUrl()
 {
     m_items.clear();
@@ -1009,7 +1146,7 @@ void KDirListerTest::testRenameCurrentDirOpenUrl()
     connect(&m_dirLister, &KCoreDirLister::newItems, this, &KDirListerTest::slotNewItems);
 
     m_dirLister.openUrl(QUrl::fromLocalFile(path));
-    QSignalSpy spyCompleted(&m_dirLister, SIGNAL(completed()));
+    QSignalSpy spyCompleted(&m_dirLister, QOverload<>::of(&KCoreDirLister::completed));
     // Wait for the signal completed to be emitted
     QVERIFY(spyCompleted.wait(1000));
     QVERIFY(m_dirLister.isFinished());
@@ -1019,9 +1156,16 @@ void KDirListerTest::testRenameCurrentDirOpenUrl()
 
     org::kde::KDirNotify::emitFileRenamed(QUrl::fromLocalFile(path), QUrl::fromLocalFile(newPath));
 
-    //Connect the redirection to openURL, so that on a rename the new location is opened.
-    //This matches usage in gwenview, and crashes
-    connect(&m_dirLister, QOverload<const QUrl&>::of(&KCoreDirLister::redirection), this, &KDirListerTest::slotOpenUrlOnRename);
+    // Connect the redirection to openURL, so that on a rename the new location is opened.
+    // This matches usage in gwenview, and crashes
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 80)
+    connect(&m_dirLister, QOverload<const QUrl &>::of(&KCoreDirLister::redirection), this, &KDirListerTest::slotOpenUrlOnRename);
+#else
+    connect(&m_dirLister, QOverload<const QUrl &, const QUrl &>::of(&KCoreDirLister::redirection), this, [this](const QUrl &, const QUrl &newUrl) {
+        slotOpenUrlOnRename(newUrl);
+    });
+#endif
+
     QTRY_VERIFY(m_dirLister.isFinished());
     disconnect(&m_dirLister, nullptr, this, nullptr);
     QDir().rmdir(newPath);
@@ -1046,7 +1190,12 @@ void KDirListerTest::testRedirection()
     QCOMPARE(m_dirLister.spyCanceled.count(), 0);
     QCOMPARE(m_dirLister.spyCanceledQUrl.count(), 0);
     QCOMPARE(m_dirLister.spyClear.count(), 1);
+
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
     QCOMPARE(m_dirLister.spyClearQUrl.count(), 0);
+#endif
+    QCOMPARE(m_dirLister.spyClearDir.count(), 0);
+
     QCOMPARE(m_dirLister.spyRedirection.count(), 0);
     QCOMPARE(m_items.count(), 0);
     QVERIFY(!m_dirLister.isFinished());
@@ -1059,7 +1208,12 @@ void KDirListerTest::testRedirection()
     QCOMPARE(m_dirLister.spyCanceled.count(), 0);
     QCOMPARE(m_dirLister.spyCanceledQUrl.count(), 0);
     QTRY_COMPARE(m_dirLister.spyClear.count(), 2); // redirection cleared a second time (just in case...)
+
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
     QCOMPARE(m_dirLister.spyClearQUrl.count(), 0);
+#endif
+    QCOMPARE(m_dirLister.spyClearDir.count(), 0);
+
     QTRY_COMPARE(m_dirLister.spyRedirection.count(), 1);
     QVERIFY(m_items.isEmpty());
     QVERIFY(!m_dirLister.isFinished());
@@ -1079,7 +1233,7 @@ void KDirListerTest::testListEmptyDirFromCache() // #278431
     // List and watch an empty dir
     connect(&m_dirLister, &KCoreDirLister::newItems, this, &KDirListerTest::slotNewItems);
     m_dirLister.openUrl(url);
-    QSignalSpy spyCompleted(&m_dirLister, SIGNAL(completed()));
+    QSignalSpy spyCompleted(&m_dirLister, QOverload<>::of(&KCoreDirLister::completed));
     QVERIFY(spyCompleted.wait(1000));
     QVERIFY(m_dirLister.isFinished());
     QVERIFY(m_items.isEmpty());
@@ -1097,10 +1251,10 @@ void KDirListerTest::testListEmptyDirFromCache() // #278431
     // due to the if (!itemU->lstItems.isEmpty()) check which is now removed.
 
     QVERIFY(!secondDirLister.isFinished()); // we didn't go to the event loop yet
-    QSignalSpy spySecondCompleted(&secondDirLister, SIGNAL(completed()));
+    QSignalSpy spySecondCompleted(&secondDirLister, QOverload<>::of(&KCoreDirLister::completed));
     QVERIFY(spySecondCompleted.wait(1000));
     if (!thirdDirLister.isFinished()) {
-        QSignalSpy spyThirdCompleted(&thirdDirLister, SIGNAL(completed()));
+        QSignalSpy spyThirdCompleted(&thirdDirLister, QOverload<>::of(&KCoreDirLister::completed));
         QVERIFY(spyThirdCompleted.wait(1000));
     }
 }
@@ -1115,7 +1269,7 @@ void KDirListerTest::testWatchingAfterCopyJob() // #331582
     // List and watch an empty dir
     connect(&m_dirLister, &KCoreDirLister::newItems, this, &KDirListerTest::slotNewItems);
     m_dirLister.openUrl(QUrl::fromLocalFile(path));
-    QSignalSpy spyCompleted(&m_dirLister, SIGNAL(completed()));
+    QSignalSpy spyCompleted(&m_dirLister, QOverload<>::of(&KCoreDirLister::completed));
     QVERIFY(spyCompleted.wait(1000));
     QVERIFY(m_dirLister.isFinished());
     QVERIFY(m_items.isEmpty());
@@ -1153,7 +1307,7 @@ void KDirListerTest::testWatchingAfterCopyJob() // #331582
     QTRY_COMPARE(m_items.count(), 1);
 
     newDir.remove();
-    QSignalSpy clearSpy(&m_dirLister, SIGNAL(clear()));
+    QSignalSpy clearSpy(&m_dirLister, QOverload<>::of(&KCoreDirLister::clear));
     QVERIFY(clearSpy.wait(1000));
 }
 
@@ -1167,7 +1321,7 @@ void KDirListerTest::testRemoveWatchedDirectory()
     // List and watch an empty dir
     connect(&m_dirLister, &KCoreDirLister::newItems, this, &KDirListerTest::slotNewItems);
     m_dirLister.openUrl(QUrl::fromLocalFile(path));
-    QSignalSpy spyCompleted(&m_dirLister, SIGNAL(completed()));
+    QSignalSpy spyCompleted(&m_dirLister, QOverload<>::of(&KCoreDirLister::completed));
     QVERIFY(spyCompleted.wait(1000));
     QTRY_VERIFY(m_dirLister.isFinished());
     QTRY_VERIFY(m_items.isEmpty());
@@ -1210,7 +1364,7 @@ void KDirListerTest::testDirPermissionChange()
 
     MyDirLister mylister;
     mylister.openUrl(QUrl::fromLocalFile(tempDir.path()));
-    QSignalSpy spyCompleted(&mylister, SIGNAL(completed()));
+    QSignalSpy spyCompleted(&mylister, QOverload<>::of(&KCoreDirLister::completed));
     QVERIFY(spyCompleted.wait(1000));
 
     KFileItemList list = mylister.items();
@@ -1240,13 +1394,13 @@ void KDirListerTest::slotNewItems2(const KFileItemList &lst)
     m_items2 += lst;
 }
 
-void KDirListerTest::slotRefreshItems(const QList<QPair<KFileItem, KFileItem> > &lst)
+void KDirListerTest::slotRefreshItems(const QList<QPair<KFileItem, KFileItem>> &lst)
 {
     m_refreshedItems += lst;
-    emit refreshItemsReceived();
+    Q_EMIT refreshItemsReceived();
 }
 
-void KDirListerTest::slotRefreshItems2(const QList<QPair<KFileItem, KFileItem> > &lst)
+void KDirListerTest::slotRefreshItems2(const QList<QPair<KFileItem, KFileItem>> &lst)
 {
     m_refreshedItems2 += lst;
 }
@@ -1260,7 +1414,7 @@ void KDirListerTest::testCopyAfterListingAndMove() // #353195
 
     // ensure m_dirLister holds the items.
     m_dirLister.openUrl(QUrl::fromLocalFile(path()), KDirLister::NoFlags);
-    QSignalSpy spyCompleted(&m_dirLister, SIGNAL(completed()));
+    QSignalSpy spyCompleted(&m_dirLister, QOverload<>::of(&KCoreDirLister::completed));
     QVERIFY(spyCompleted.wait());
 
     // Move b into a
@@ -1290,38 +1444,44 @@ void KDirListerTest::testRenameDirectory() // #401552
     const QString dirW2 = m_tempDir.path() + "/w/Files/Files";
     QVERIFY(QDir().mkdir(dirW2));
     // Place some empty files in each directory
-    for (int i=0; i < 50; i++) {
+    for (int i = 0; i < 50; i++) {
         createSimpleFile(dirW + QString("t_%1").arg(i));
     }
-    for (int i=0; i < 50; i++) {
+    for (int i = 0; i < 50; i++) {
         createSimpleFile(dirW + QString("z_%1").arg(i));
     }
     // Place some empty files with prefix Files in w. Note that / is missing.
-    for (int i=0; i < 50; i++) {
+    for (int i = 0; i < 50; i++) {
         createSimpleFile(dirW1 + QString("t_%1").arg(i));
     }
-    for (int i=0; i < 50; i++) {
+    for (int i = 0; i < 50; i++) {
         createSimpleFile(dirW1 + QString("z_%1").arg(i));
     }
     // Place some empty files with prefix Files in w/Files. Note that / is missing.
-    for (int i=0; i < 50; i++) {
+    for (int i = 0; i < 50; i++) {
         createSimpleFile(dirW2 + QString("t_%1").arg(i));
     }
-    for (int i=0; i < 50; i++) {
+    for (int i = 0; i < 50; i++) {
         createSimpleFile(dirW2 + QString("z_%1").arg(i));
     }
     // Listen to the w directory
     m_dirLister.openUrl(QUrl::fromLocalFile(dirW), KDirLister::NoFlags);
 
     // Try to reproduce the bug #401552 renaming the w directory several times if needed
-    const QStringList dirs = { dirW + "___", dirW + QLatin1Char('_'), dirW + "______",  dirW + "_c",
-        dirW + "___", dirW + "_________" };
+    const QStringList dirs = {dirW + "___", dirW + QLatin1Char('_'), dirW + "______", dirW + "_c", dirW + "___", dirW + "_________"};
 
     QString currDir = dirW;
     KIO::SimpleJob *job = nullptr;
-    //Connect the redirection to openURL, so that on a rename the new location is opened.
-    connect(&m_dirLister, QOverload<const QUrl&>::of(&KCoreDirLister::redirection), this, &KDirListerTest::slotOpenUrlOnRename);
-    for (int i=0; i < dirs.size(); i++) {
+    // Connect the redirection to openURL, so that on a rename the new location is opened.
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 80)
+    connect(&m_dirLister, QOverload<const QUrl &>::of(&KCoreDirLister::redirection), this, &KDirListerTest::slotOpenUrlOnRename);
+#else
+    connect(&m_dirLister, QOverload<const QUrl &, const QUrl &>::of(&KCoreDirLister::redirection), this, [this](const QUrl &, const QUrl &newUrl) {
+        slotOpenUrlOnRename(newUrl);
+    });
+#endif
+
+    for (int i = 0; i < dirs.size(); i++) {
         // Wait for the listener to get all files
         QTRY_VERIFY(m_dirLister.isFinished());
         // Do the rename
@@ -1334,7 +1494,6 @@ void KDirListerTest::testRenameDirectory() // #401552
     disconnect(&m_dirLister, nullptr, this, nullptr);
 }
 
-
 void KDirListerTest::testDeleteCurrentDir()
 {
     // ensure m_dirLister holds the items.
@@ -1344,12 +1503,17 @@ void KDirListerTest::testDeleteCurrentDir()
     bool ok = job->exec();
     QVERIFY(ok);
     QTRY_COMPARE(m_dirLister.spyClear.count(), 1);
+
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
     QCOMPARE(m_dirLister.spyClearQUrl.count(), 0);
+#endif
+    QCOMPARE(m_dirLister.spyClearDir.count(), 0);
+
     QList<QUrl> deletedUrls;
     for (int i = 0; i < m_dirLister.spyItemsDeleted.count(); ++i) {
         deletedUrls += m_dirLister.spyItemsDeleted[i][0].value<KFileItemList>().urlList();
     }
-    //qDebug() << deletedUrls;
+    // qDebug() << deletedUrls;
     QUrl currentDirUrl = QUrl::fromLocalFile(path()).adjusted(QUrl::StripTrailingSlash);
     // Sometimes I get ("current/subdir", "current") here, but that seems ok.
     QVERIFY(deletedUrls.contains(currentDirUrl));
@@ -1403,7 +1567,7 @@ void KDirListerTest::waitUntilAfter(const QDateTime &ctime)
             break;
         }
     }
-    //if (totalWait > 0)
+    // if (totalWait > 0)
     qDebug() << "Waited" << totalWait << "ms so that now" << now.toString(Qt::ISODate) << "is >" << ctime.toString(Qt::ISODate);
 }
 
