@@ -1,20 +1,8 @@
-/* This file is part of the KDE project
-   Copyright (C) 2002-2006 Michael Brade <brade@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2002-2006 Michael Brade <brade@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KCOREDIRLISTER_P_H
@@ -22,18 +10,20 @@
 
 #include "kfileitem.h"
 
-#include <QMap>
-#include <QHash>
 #include <QCache>
-#include <QSet>
-#include <QTimer>
 #include <QCoreApplication>
 #include <QFileInfo>
+#include <QHash>
+#include <QMap>
+#include <QSet>
+#include <QTimer>
 #include <QUrl>
+#include <QVector>
 
+#include <KDirWatch>
 #include <kio/global.h>
-#include <kdirwatch.h>
 
+class QRegularExpression;
 class KCoreDirLister;
 namespace KIO
 {
@@ -43,11 +33,11 @@ class ListJob;
 class OrgKdeKDirNotifyInterface;
 struct KCoreDirListerCacheDirectoryData;
 
-class Q_DECL_HIDDEN KCoreDirLister::Private
+class KCoreDirListerPrivate
 {
 public:
-    explicit Private(KCoreDirLister *parent)
-        : m_parent(parent)
+    explicit KCoreDirListerPrivate(KCoreDirLister *qq)
+        : q(qq)
     {
         complete = false;
 
@@ -60,12 +50,12 @@ public:
         hasPendingChanges = false;
     }
 
-    void _k_emitCachedItems(const QUrl &, bool, bool);
-    void _k_slotInfoMessage(KJob *, const QString &);
-    void _k_slotPercent(KJob *, unsigned long);
-    void _k_slotTotalSize(KJob *, qulonglong);
-    void _k_slotProcessedSize(KJob *, qulonglong);
-    void _k_slotSpeed(KJob *, unsigned long);
+    void emitCachedItems(const QUrl &, bool, bool);
+    void slotInfoMessage(KJob *, const QString &);
+    void slotPercent(KJob *, unsigned long);
+    void slotTotalSize(KJob *, qulonglong);
+    void slotProcessedSize(KJob *, qulonglong);
+    void slotSpeed(KJob *, unsigned long);
 
     bool doMimeExcludeFilter(const QString &mimeExclude, const QStringList &filters) const;
     void connectJob(KIO::ListJob *);
@@ -102,7 +92,7 @@ public:
     class CachedItemsJob;
     CachedItemsJob *cachedItemsJobForUrl(const QUrl &url) const;
 
-    KCoreDirLister * const m_parent;
+    KCoreDirLister *const q;
 
     /**
      * List of dirs handled by this dirlister. The first entry is the base URL.
@@ -113,13 +103,13 @@ public:
     // toplevel URL
     QUrl url;
 
-    bool complete: 1;
+    bool complete : 1;
 
-    bool autoUpdate: 1;
+    bool autoUpdate : 1;
 
-    bool delayedMimeTypes: 1;
+    bool delayedMimeTypes : 1;
 
-    bool hasPendingChanges: 1; // i.e. settings != oldSettings
+    bool hasPendingChanges : 1; // i.e. settings != oldSettings
 
     struct JobData {
         long unsigned int percent, speed;
@@ -133,7 +123,7 @@ public:
 
     typedef QHash<QUrl, KFileItemList> NewItemsHash;
     NewItemsHash lstNewItems;
-    QList<QPair<KFileItem, KFileItem> > lstRefreshItems;
+    QList<QPair<KFileItem, KFileItem>> lstRefreshItems;
     KFileItemList lstMimeFilteredItems, lstRemoveItems;
 
     QList<CachedItemsJob *> m_cachedItemsJobs;
@@ -141,10 +131,14 @@ public:
     QString nameFilter; // parsed into lstFilters
 
     struct FilterSettings {
-        FilterSettings() : isShowingDotFiles(false), dirOnlyMode(false) {}
+        FilterSettings()
+            : isShowingDotFiles(false)
+            , dirOnlyMode(false)
+        {
+        }
         bool isShowingDotFiles;
         bool dirOnlyMode;
-        QList<QRegExp> lstFilters;
+        QVector<QRegularExpression> lstFilters;
         QStringList mimeFilter;
         QStringList mimeExcludeFilter;
     };
@@ -199,11 +193,9 @@ public:
 
     // Called by CachedItemsJob:
     // Emits the cached items, for this lister and this url
-    void emitItemsFromCache(KCoreDirLister::Private::CachedItemsJob *job, KCoreDirLister *lister,
-                            const QUrl &_url, bool _reload, bool _emitCompleted);
+    void emitItemsFromCache(KCoreDirListerPrivate::CachedItemsJob *job, KCoreDirLister *lister, const QUrl &_url, bool _reload, bool _emitCompleted);
     // Called by CachedItemsJob:
-    void forgetCachedItemsJob(KCoreDirLister::Private::CachedItemsJob *job, KCoreDirLister *lister,
-                              const QUrl &url);
+    void forgetCachedItemsJob(KCoreDirListerPrivate::CachedItemsJob *job, KCoreDirLister *lister, const QUrl &url);
 
 public Q_SLOTS:
     /**
@@ -251,8 +243,6 @@ private:
     class DirItem;
     DirItem *dirItemForUrl(const QUrl &dir) const;
 
-    bool validUrl(KCoreDirLister *lister, const QUrl &_url) const;
-
     void stopListJob(const QUrl &url, bool silent);
 
     KIO::ListJob *jobForUrl(const QUrl &url, KIO::ListJob *not_job = nullptr);
@@ -272,7 +262,7 @@ private:
     // when there were items deleted from the filesystem all the listers holding
     // the parent directory need to be notified, the items have to be deleted
     // and removed from the cache including all the children.
-    void deleteUnmarkedItems(const QList<KCoreDirLister *>&, QList<KFileItem> &lstItems, const QHash<QString, KFileItem> &itemsToDelete);
+    void deleteUnmarkedItems(const QList<KCoreDirLister *> &, QList<KFileItem> &lstItems, const QHash<QString, KFileItem> &itemsToDelete);
 
     // Helper method called when we know that a list of items was deleted
     void itemsDeleted(const QList<KCoreDirLister *> &listers, const KFileItemList &deletedItems);
@@ -325,7 +315,7 @@ private:
      * @param dir path to the target directory.
      * @return names listed in the directory's ".hidden" file (empty if it doesn't exist).
      */
-    QSet<QString> filesInDotHiddenForDir(const QString& dir);
+    QSet<QString> filesInDotHiddenForDir(const QString &dir);
 
 #ifndef NDEBUG
     void printDebug();
@@ -335,7 +325,8 @@ private:
     {
     public:
         DirItem(const QUrl &dir, const QString &canonicalPath)
-            : url(dir), m_canonicalPath(canonicalPath)
+            : url(dir)
+            , m_canonicalPath(canonicalPath)
         {
             autoUpdates = 0;
             complete = false;
@@ -358,6 +349,9 @@ private:
             lstItems.clear();
         }
 
+        DirItem(const DirItem &) = delete;
+        DirItem &operator=(const DirItem &) = delete;
+
         void sendSignal(bool entering, const QUrl &url)
         {
             // Note that "entering" means "start watching", and "leaving" means "stop watching"
@@ -446,13 +440,16 @@ private:
 
     // definition of the cache of ".hidden" files
     struct CacheHiddenFile {
-        CacheHiddenFile(const QDateTime& mtime, const QSet<QString>& listedFiles)
-            : mtime(mtime), listedFiles(listedFiles) { }
+        CacheHiddenFile(const QDateTime &mtime, const QSet<QString> &listedFiles)
+            : mtime(mtime)
+            , listedFiles(listedFiles)
+        {
+        }
         QDateTime mtime;
         QSet<QString> listedFiles;
     };
 
-    //static const unsigned short MAX_JOBS_PER_LISTER;
+    // static const unsigned short MAX_JOBS_PER_LISTER;
 
     QMap<KIO::ListJob *, KIO::UDSEntryList> runningListJobs;
 
@@ -480,7 +477,7 @@ private:
 
     // Set of remote files that have changed recently -- but we can't emit those
     // changes yet, we need to wait for the "update" directory listing.
-    // The cmp() call can't differ mimetypes since they are determined on demand,
+    // The cmp() call can't differ MIME types since they are determined on demand,
     // this is why we need to remember those files here.
     QSet<KFileItem> pendingRemoteUpdates;
 
@@ -507,13 +504,13 @@ struct KCoreDirListerCacheDirectoryData {
     void moveListersWithoutCachedItemsJob(const QUrl &url);
 };
 
-//const unsigned short KCoreDirListerCache::MAX_JOBS_PER_LISTER = 5;
+// const unsigned short KCoreDirListerCache::MAX_JOBS_PER_LISTER = 5;
 
 // This job tells KCoreDirListerCache to emit cached items asynchronously from listDir()
 // to give the KCoreDirLister user enough time for connecting to its signals, and so
 // that KCoreDirListerCache behaves just like when a real KIO::Job is used: nothing
 // is emitted during the openUrl call itself.
-class KCoreDirLister::Private::CachedItemsJob : public KJob
+class KCoreDirListerPrivate::CachedItemsJob : public KJob
 {
     Q_OBJECT
 public:
