@@ -1,20 +1,8 @@
-/*  This file is part of the KDE project
-    Copyright (C) 2007 Kevin Ottens <ervin@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2007 Kevin Ottens <ervin@kde.org>
 
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "kfileplacesitem_p.h"
@@ -22,30 +10,32 @@
 #include <QDateTime>
 #include <QIcon>
 
-#include <kbookmarkmanager.h>
-#include <kiconloader.h>
-#include <klocalizedstring.h>
+#include <KBookmarkManager>
 #include <KConfig>
 #include <KConfigGroup>
+#include <KIconLoader>
+#include <KLocalizedString>
+#include <KMountPoint>
 #include <kprotocolinfo.h>
 #include <solid/block.h>
 #include <solid/networkshare.h>
 #include <solid/opticaldisc.h>
 #include <solid/opticaldrive.h>
-#include <solid/storageaccess.h>
-#include <solid/storagevolume.h>
-#include <solid/storagedrive.h>
 #include <solid/portablemediaplayer.h>
+#include <solid/storageaccess.h>
+#include <solid/storagedrive.h>
+#include <solid/storagevolume.h>
 
-static bool isTrash(const KBookmark &bk) {
+static bool isTrash(const KBookmark &bk)
+{
     return bk.url().toString() == QLatin1String("trash:/");
 }
 
-KFilePlacesItem::KFilePlacesItem(KBookmarkManager *manager,
-                                 const QString &address,
-                                 const QString &udi)
-    : m_manager(manager), m_folderIsEmpty(true), m_isCdrom(false),
-      m_isAccessible(false)
+KFilePlacesItem::KFilePlacesItem(KBookmarkManager *manager, const QString &address, const QString &udi)
+    : m_manager(manager)
+    , m_folderIsEmpty(true)
+    , m_isCdrom(false)
+    , m_isAccessible(false)
 {
     updateDeviceInfo(udi);
     setBookmark(m_manager->findByAddress(address));
@@ -59,6 +49,17 @@ KFilePlacesItem::KFilePlacesItem(KBookmarkManager *manager,
             m_folderIsEmpty = group.readEntry("Empty", true);
         }
     }
+
+    // Hide SSHFS network device mounted by kdeconnect, since we already have the kdeconnect:// place.
+    if (isDevice() && m_access && device().vendor() == QLatin1String("fuse.sshfs")) {
+        auto mountPoint = KMountPoint::currentMountPoints().findByPath(m_access->filePath());
+        if (mountPoint->mountedFrom().startsWith(QLatin1String("kdeconnect@"))) {
+            // Hide only if the user never set the "Hide" checkbox on the device.
+            if (m_bookmark.metaDataItem(QStringLiteral("IsHidden")).isEmpty()) {
+                setHidden(true);
+            }
+        }
+    }
 }
 
 KFilePlacesItem::~KFilePlacesItem()
@@ -74,6 +75,33 @@ QString KFilePlacesItem::id() const
     }
 }
 
+bool KFilePlacesItem::hasSupportedScheme(const QStringList &schemes) const
+{
+    if (schemes.isEmpty()) {
+        return true;
+    }
+
+    // StorageAccess is always local, doesn't need to be accessible to know this
+    if (m_access && schemes.contains(QLatin1String("file"))) {
+        return true;
+    }
+
+    if (m_networkShare && schemes.contains(m_networkShare->url().scheme())) {
+        return true;
+    }
+
+    if (m_player) {
+        const QStringList protocols = m_player->supportedProtocols();
+        for (const QString &protocol : protocols) {
+            if (schemes.contains(protocol)) {
+                return true;
+            }
+        }
+    }
+
+    return false;
+}
+
 bool KFilePlacesItem::isDevice() const
 {
     return !bookmark().metaDataItem(QStringLiteral("UDI")).isEmpty();
@@ -139,8 +167,7 @@ QVariant KFilePlacesItem::data(int role) const
 {
     if (role == KFilePlacesModel::GroupRole) {
         return QVariant(m_groupName);
-    } else if (role != KFilePlacesModel::HiddenRole &&
-                role != Qt::BackgroundRole && isDevice()) {
+    } else if (role != KFilePlacesModel::HiddenRole && role != Qt::BackgroundRole && isDevice()) {
         return deviceData(role);
     } else {
         return bookmarkData(role);
@@ -151,8 +178,7 @@ KFilePlacesModel::GroupType KFilePlacesItem::groupType() const
 {
     if (!isDevice()) {
         const QString protocol = bookmark().url().scheme();
-        if (protocol == QLatin1String("timeline") ||
-            protocol == QLatin1String("recentlyused")) {
+        if (protocol == QLatin1String("timeline") || protocol == QLatin1String("recentlyused")) {
             return KFilePlacesModel::RecentlySavedType;
         }
 
@@ -160,9 +186,7 @@ KFilePlacesModel::GroupType KFilePlacesItem::groupType() const
             return KFilePlacesModel::SearchForType;
         }
 
-        if (protocol == QLatin1String("bluetooth") ||
-            protocol == QLatin1String("obexftp") ||
-            protocol == QLatin1String("kdeconnect")) {
+        if (protocol == QLatin1String("bluetooth") || protocol == QLatin1String("obexftp") || protocol == QLatin1String("kdeconnect")) {
             return KFilePlacesModel::DevicesType;
         }
 
@@ -170,8 +194,7 @@ KFilePlacesModel::GroupType KFilePlacesItem::groupType() const
             return KFilePlacesModel::TagsType;
         }
 
-        if (protocol == QLatin1String("remote") ||
-            KProtocolInfo::protocolClass(protocol) != QLatin1String(":local")) {
+        if (protocol == QLatin1String("remote") || KProtocolInfo::protocolClass(protocol) != QLatin1String(":local")) {
             return KFilePlacesModel::RemoteType;
         } else {
             return KFilePlacesModel::PlacesType;
@@ -239,7 +262,7 @@ QVariant KFilePlacesItem::deviceData(int role) const
     if (d.isValid()) {
         switch (role) {
         case Qt::DisplayRole:
-            return d.description();
+            return d.displayName();
         case Qt::DecorationRole:
             return KDE::icon(m_iconPath, m_emblems);
         case KFilePlacesModel::UrlRole:
@@ -256,8 +279,12 @@ QVariant KFilePlacesItem::deviceData(int role) const
                 // figure it out, but cannot handle multiple disc drives.
                 // See https://bugs.kde.org/show_bug.cgi?id=314544#c40
                 return QUrl(QStringLiteral("audiocd:/"));
-            } else if (m_mtp) {
-                return QUrl(QStringLiteral("mtp:udi=%1").arg(d.udi()));
+            } else if (m_player) {
+                const QStringList protocols = m_player->supportedProtocols();
+                if (!protocols.isEmpty()) {
+                    return QUrl(QStringLiteral("%1:udi=%2").arg(protocols.first(), d.udi()));
+                }
+                return QVariant();
             } else {
                 return QVariant();
             }
@@ -289,11 +316,7 @@ QVariant KFilePlacesItem::deviceData(int role) const
     }
 }
 
-KBookmark KFilePlacesItem::createBookmark(KBookmarkManager *manager,
-        const QString &label,
-        const QUrl &url,
-        const QString &iconName,
-        KFilePlacesItem *after)
+KBookmark KFilePlacesItem::createBookmark(KBookmarkManager *manager, const QString &label, const QUrl &url, const QString &iconName, KFilePlacesItem *after)
 {
     KBookmarkGroup root = manager->root();
     if (root.isNull()) {
@@ -318,23 +341,26 @@ KBookmark KFilePlacesItem::createBookmark(KBookmarkManager *manager,
 }
 
 KBookmark KFilePlacesItem::createSystemBookmark(KBookmarkManager *manager,
-        const QString &translationContext,
-        const QString &untranslatedLabel,
-        const QUrl &url,
-        const QString &iconName)
+                                                const char *translationContext,
+                                                const QByteArray &untranslatedLabel,
+                                                const QUrl &url,
+                                                const QString &iconName,
+                                                const KBookmark &after)
 {
     Q_UNUSED(translationContext); // parameter is only necessary to force the caller
     // to provide a marked-for-translation string for the label, with context
 
-    KBookmark bookmark = createBookmark(manager, untranslatedLabel, url, iconName);
+    KBookmark bookmark = createBookmark(manager, QString::fromUtf8(untranslatedLabel), url, iconName);
     if (!bookmark.isNull()) {
         bookmark.setMetaDataItem(QStringLiteral("isSystemItem"), QStringLiteral("true"));
     }
+    if (!after.isNull()) {
+        manager->root().moveBookmark(bookmark, after);
+    }
     return bookmark;
 }
 
-KBookmark KFilePlacesItem::createDeviceBookmark(KBookmarkManager *manager,
-        const QString &udi)
+KBookmark KFilePlacesItem::createDeviceBookmark(KBookmarkManager *manager, const QString &udi)
 {
     KBookmarkGroup root = manager->root();
     if (root.isNull()) {
@@ -346,10 +372,9 @@ KBookmark KFilePlacesItem::createDeviceBookmark(KBookmarkManager *manager,
     return bookmark;
 }
 
-KBookmark KFilePlacesItem::createTagBookmark(KBookmarkManager *manager,
-        const QString &tag)
+KBookmark KFilePlacesItem::createTagBookmark(KBookmarkManager *manager, const QString &tag)
 {
-    KBookmark bookmark = createSystemBookmark(manager, tag, tag, QUrl(QLatin1String("tags:/") + tag), QLatin1String("tag"));
+    KBookmark bookmark = createSystemBookmark(manager, tag.toUtf8().data(), tag.toUtf8(), QUrl(QLatin1String("tags:/") + tag), QLatin1String("tag"));
     bookmark.setMetaDataItem(QStringLiteral("tag"), tag);
     bookmark.setMetaDataItem(QStringLiteral("isSystemItem"), QStringLiteral("true"));
 
@@ -360,13 +385,12 @@ QString KFilePlacesItem::generateNewId()
 {
     static int count = 0;
 
-//    return QString::number(count++);
+    //    return QString::number(count++);
 
-    return QString::number(QDateTime::currentSecsSinceEpoch())
-           + QLatin1Char('/') + QString::number(count++);
+    return QString::number(QDateTime::currentSecsSinceEpoch()) + QLatin1Char('/') + QString::number(count++);
 
-//    return QString::number(QDateTime::currentSecsSinceEpoch())
-//         + '/' + QString::number(qrand());
+    //    return QString::number(QDateTime::currentSecsSinceEpoch())
+    //         + '/' + QString::number(qrand());
 }
 
 bool KFilePlacesItem::updateDeviceInfo(const QString &udi)
@@ -384,7 +408,7 @@ bool KFilePlacesItem::updateDeviceInfo(const QString &udi)
         m_access = m_device.as<Solid::StorageAccess>();
         m_volume = m_device.as<Solid::StorageVolume>();
         m_disc = m_device.as<Solid::OpticalDisc>();
-        m_mtp = m_device.as<Solid::PortableMediaPlayer>();
+        m_player = m_device.as<Solid::PortableMediaPlayer>();
         m_networkShare = m_device.as<Solid::NetworkShare>();
         m_iconPath = m_device.icon();
         m_emblems = m_device.emblems();
@@ -397,15 +421,14 @@ bool KFilePlacesItem::updateDeviceInfo(const QString &udi)
         }
 
         if (m_access) {
-            connect(m_access.data(), &Solid::StorageAccess::accessibilityChanged,
-                    this, &KFilePlacesItem::onAccessibilityChanged);
+            connect(m_access.data(), &Solid::StorageAccess::accessibilityChanged, this, &KFilePlacesItem::onAccessibilityChanged);
             onAccessibilityChanged(m_access->isAccessible());
         }
     } else {
         m_access = nullptr;
         m_volume = nullptr;
         m_disc = nullptr;
-        m_mtp = nullptr;
+        m_player = nullptr;
         m_drive = nullptr;
         m_networkShare = nullptr;
         m_iconPath.clear();
@@ -421,7 +444,7 @@ void KFilePlacesItem::onAccessibilityChanged(bool isAccessible)
     m_isCdrom = m_device.is<Solid::OpticalDrive>() || m_device.parent().is<Solid::OpticalDrive>();
     m_emblems = m_device.emblems();
 
-    emit itemChanged(id());
+    Q_EMIT itemChanged(id());
 }
 
 QString KFilePlacesItem::iconNameForBookmark(const KBookmark &bookmark) const
