@@ -1,60 +1,42 @@
-/***************************************************************************
- *   Copyright (C) 2006 by Peter Penz (peter.penz@gmx.at)                  *
- *   Copyright (C) 2007 by Kevin Ottens (ervin@kde.org)                    *
- *                                                                         *
- *   This library is free software; you can redistribute it and/or         *
- *   modify it under the terms of the GNU Lesser General Public            *
- *   License as published by the Free Software Foundation; either          *
- *   version 2 of the License, or (at your option) any later version.      *
- *                                                                         *
- *   This library is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
- *   Lesser General Public License for more details.                       *
- *                                                                         *
- *   You should have received a copy of the GNU Lesser General Public      *
- *   License along with this library; if not, write to the                 *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2006 Peter Penz <peter.penz@gmx.at>
+    SPDX-FileCopyrightText: 2007 Kevin Ottens <ervin@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "kurlnavigatorplacesselector_p.h"
 
+#include <KUrlMimeData>
 #include <kfileplacesmodel.h>
-#include <kurlmimedata.h>
 
-#include <qmimedatabase.h>
 #include <QDragEnterEvent>
 #include <QDragLeaveEvent>
 #include <QDropEvent>
 #include <QMenu>
+#include <QMimeData>
+#include <QMimeDatabase>
+#include <QMouseEvent>
 #include <QPainter>
 #include <QPixmap>
 #include <QStyle>
-#include <QMimeData>
 
 namespace KDEPrivate
 {
-
-KUrlNavigatorPlacesSelector::KUrlNavigatorPlacesSelector(QWidget *parent, KFilePlacesModel *placesModel) :
-    KUrlNavigatorButtonBase(parent),
-    m_selectedItem(-1),
-    m_placesModel(placesModel)
+KUrlNavigatorPlacesSelector::KUrlNavigatorPlacesSelector(KUrlNavigator *parent, KFilePlacesModel *placesModel)
+    : KUrlNavigatorButtonBase(parent)
+    , m_selectedItem(-1)
+    , m_placesModel(placesModel)
 {
     setFocusPolicy(Qt::NoFocus);
 
     m_placesMenu = new QMenu(this);
+    m_placesMenu->installEventFilter(this);
 
     updateMenu();
 
-    connect(m_placesModel, SIGNAL(rowsInserted(QModelIndex,int,int)),
-            this, SLOT(updateMenu()));
-    connect(m_placesModel, SIGNAL(rowsRemoved(QModelIndex,int,int)),
-            this, SLOT(updateMenu()));
-    connect(m_placesModel, SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-            this, SLOT(updateMenu()));
-    connect(m_placesMenu, SIGNAL(triggered(QAction*)),
-            this, SLOT(activatePlace(QAction*)));
+    connect(m_placesModel, &KFilePlacesModel::reloaded, this, &KUrlNavigatorPlacesSelector::updateMenu);
+    connect(m_placesMenu, &QMenu::triggered, this, &KUrlNavigatorPlacesSelector::activatePlace);
 
     setMenu(m_placesMenu);
 
@@ -69,15 +51,49 @@ void KUrlNavigatorPlacesSelector::updateMenu()
 {
     m_placesMenu->clear();
 
+    // Submenus have to be deleted explicitly (QTBUG-11070)
+    for (QObject *obj : QObjectList(m_placesMenu->children())) {
+        delete qobject_cast<QMenu *>(obj); // Noop for nullptr
+    }
+
     updateSelection(m_selectedUrl);
+
+    QString previousGroup;
+    QMenu *subMenu = nullptr;
+
     const int rowCount = m_placesModel->rowCount();
     for (int i = 0; i < rowCount; ++i) {
         QModelIndex index = m_placesModel->index(i, 0);
-        QAction *action = new QAction(m_placesModel->icon(index),
-                                      m_placesModel->text(index),
-                                      m_placesMenu);
-        m_placesMenu->addAction(action);
-        action->setData(i);
+        if (m_placesModel->isHidden(index)) {
+            continue;
+        }
+
+        QAction *placeAction = new QAction(m_placesModel->icon(index), m_placesModel->text(index), m_placesMenu);
+        placeAction->setData(i);
+
+        const QString &groupName = index.data(KFilePlacesModel::GroupRole).toString();
+        if (previousGroup.isEmpty()) { // Skip first group heading.
+            previousGroup = groupName;
+        }
+
+        // Put all subsequent categories into a submenu.
+        if (previousGroup != groupName) {
+            QAction *subMenuAction = new QAction(groupName, m_placesMenu);
+            subMenu = new QMenu(m_placesMenu);
+            subMenu->installEventFilter(this);
+            subMenuAction->setMenu(subMenu);
+
+            m_placesMenu->addAction(subMenuAction);
+
+            previousGroup = groupName;
+        }
+
+        if (subMenu) {
+            subMenu->addAction(placeAction);
+        } else {
+            m_placesMenu->addAction(placeAction);
+        }
+
         if (i == m_selectedItem) {
             setIcon(m_placesModel->icon(index));
         }
@@ -88,26 +104,23 @@ void KUrlNavigatorPlacesSelector::updateMenu()
 
 void KUrlNavigatorPlacesSelector::updateTeardownAction()
 {
-    const int rowCount = m_placesModel->rowCount();
-    if (m_placesMenu->actions().size() == rowCount + 2) {
-        // remove teardown action
-        QAction *action = m_placesMenu->actions().at(rowCount + 1);
-        m_placesMenu->removeAction(action);
-        delete action;
+    const QString teardownActionId = QStringLiteral("teardownAction");
 
-        // remove separator
-        action = m_placesMenu->actions().at(rowCount);
-        m_placesMenu->removeAction(action);
-        delete action;
+    const auto actions = m_placesMenu->actions();
+    for (QAction *action : actions) {
+        if (action->data() == teardownActionId) {
+            delete action;
+        }
     }
 
     const QModelIndex index = m_placesModel->index(m_selectedItem, 0);
     QAction *teardown = m_placesModel->teardownActionForIndex(index);
-    if (teardown != 0) {
-        teardown->setParent(m_placesMenu);
-        teardown->setData("teardownAction");
+    if (teardown) {
+        QAction *separator = m_placesMenu->addSeparator();
+        separator->setData(teardownActionId);
 
-        m_placesMenu->addSeparator();
+        teardown->setParent(m_placesMenu);
+        teardown->setData(teardownActionId);
         m_placesMenu->addAction(teardown);
     }
 }
@@ -182,7 +195,7 @@ void KUrlNavigatorPlacesSelector::dropEvent(QDropEvent *event)
 
     QMimeDatabase db;
     const QList<QUrl> urlList = KUrlMimeData::urlsFromMimeData(event->mimeData());
-    foreach (const QUrl &url, urlList) {
+    for (const QUrl &url : urlList) {
         QMimeType mimetype = db.mimeTypeForUrl(url);
         if (mimetype.inherits(QStringLiteral("inode/directory"))) {
             m_placesModel->addPlace(url.fileName(), url);
@@ -190,9 +203,20 @@ void KUrlNavigatorPlacesSelector::dropEvent(QDropEvent *event)
     }
 }
 
+void KUrlNavigatorPlacesSelector::mouseReleaseEvent(QMouseEvent *event)
+{
+    if (event->button() == Qt::MiddleButton && geometry().contains(event->pos())) {
+        Q_EMIT tabRequested(KFilePlacesModel::convertedUrl(m_placesModel->url(m_placesModel->index(m_selectedItem, 0))));
+        event->accept();
+        return;
+    }
+
+    KUrlNavigatorButtonBase::mouseReleaseEvent(event);
+}
+
 void KUrlNavigatorPlacesSelector::activatePlace(QAction *action)
 {
-    Q_ASSERT(action != 0);
+    Q_ASSERT(action != nullptr);
     if (action->data().toString() == QLatin1String("teardownAction")) {
         QModelIndex index = m_placesModel->index(m_selectedItem, 0);
         m_placesModel->requestTeardown(index);
@@ -204,8 +228,7 @@ void KUrlNavigatorPlacesSelector::activatePlace(QAction *action)
     m_lastClickedIndex = QPersistentModelIndex();
 
     if (m_placesModel->setupNeeded(index)) {
-        connect(m_placesModel, SIGNAL(setupDone(QModelIndex,bool)),
-                this, SLOT(onStorageSetupDone(QModelIndex,bool)));
+        connect(m_placesModel, &KFilePlacesModel::setupDone, this, &KUrlNavigatorPlacesSelector::onStorageSetupDone);
 
         m_lastClickedIndex = index;
         m_placesModel->requestSetup(index);
@@ -214,24 +237,43 @@ void KUrlNavigatorPlacesSelector::activatePlace(QAction *action)
         m_selectedItem = index.row();
         setIcon(m_placesModel->icon(index));
         updateTeardownAction();
-        emit placeActivated(m_placesModel->url(index));
+        Q_EMIT placeActivated(KFilePlacesModel::convertedUrl(m_placesModel->url(index)));
     }
 }
 
 void KUrlNavigatorPlacesSelector::onStorageSetupDone(const QModelIndex &index, bool success)
 {
-    if (m_lastClickedIndex == index)  {
+    if (m_lastClickedIndex == index) {
         if (success) {
             m_selectedItem = index.row();
             setIcon(m_placesModel->icon(index));
             updateTeardownAction();
-            emit placeActivated(m_placesModel->url(index));
+            Q_EMIT placeActivated(KFilePlacesModel::convertedUrl(m_placesModel->url(index)));
         }
         m_lastClickedIndex = QPersistentModelIndex();
     }
 }
 
+bool KUrlNavigatorPlacesSelector::eventFilter(QObject *watched, QEvent *event)
+{
+    if (auto *menu = qobject_cast<QMenu *>(watched)) {
+        if (event->type() == QEvent::MouseButtonRelease) {
+            QMouseEvent *me = static_cast<QMouseEvent *>(event);
+            if (me->button() == Qt::MiddleButton) {
+                if (QAction *action = menu->activeAction()) {
+                    m_placesMenu->close(); // always close top menu
+
+                    QModelIndex index = m_placesModel->index(action->data().toInt(), 0);
+                    Q_EMIT tabRequested(KFilePlacesModel::convertedUrl(m_placesModel->url(index)));
+                    return true;
+                }
+            }
+        }
+    }
+
+    return KUrlNavigatorButtonBase::eventFilter(watched, event);
+}
+
 } // namespace KDEPrivate
 
 #include "moc_kurlnavigatorplacesselector_p.cpp"
-
