@@ -8,9 +8,9 @@
 #ifndef _KDIRLISTERTEST_GUI_H_
 #define _KDIRLISTERTEST_GUI_H_
 
-#include <QWidget>
 #include <QString>
 #include <QUrl>
+#include <QWidget>
 
 #include <kdirlister.h>
 #include <kfileitem.h>
@@ -23,7 +23,10 @@ class PrintSignals : public QObject
 {
     Q_OBJECT
 public:
-    PrintSignals() : QObject() { }
+    PrintSignals()
+        : QObject()
+    {
+    }
 
 public Q_SLOTS:
     void started(const QUrl &url)
@@ -34,7 +37,7 @@ public Q_SLOTS:
     {
         cout << "canceled()" << endl;
     }
-    void canceled(const QUrl &url)
+    void listingDirCanceled(const QUrl &url)
     {
         cout << "*** canceled( " << url.toDisplayString().toLocal8Bit().data() << " )" << endl;
     }
@@ -42,18 +45,13 @@ public Q_SLOTS:
     {
         cout << "*** completed()" << endl;
     }
-    void completed(const QUrl &url)
+    void listingDirCompleted(const QUrl &url)
     {
         cout << "*** completed( " << url.toDisplayString().toLocal8Bit().data() << " )" << endl;
     }
-    void redirection(const QUrl &url)
-    {
-        cout << "*** redirection( " << url.toDisplayString().toLocal8Bit().data() << " )" << endl;
-    }
     void redirection(const QUrl &src, const QUrl &dest)
     {
-        cout << "*** redirection( " << src.toDisplayString().toLocal8Bit().data() << ", "
-             << dest.toDisplayString().toLocal8Bit().data() << " )" << endl;
+        cout << "*** redirection( " << src.toDisplayString().toLocal8Bit().data() << ", " << dest.toDisplayString().toLocal8Bit().data() << " )" << endl;
     }
     void clear()
     {
@@ -77,7 +75,7 @@ public Q_SLOTS:
         cout << "*** itemsFilteredByMime: " << endl;
         // TODO
     }
-    void refreshItems(const QList<QPair<KFileItem, KFileItem> > &)
+    void refreshItems(const QList<QPair<KFileItem, KFileItem>> &)
     {
         cout << "*** refreshItems: " << endl;
         // TODO
@@ -112,7 +110,7 @@ class KDirListerTest : public QWidget
 {
     Q_OBJECT
 public:
-    KDirListerTest(QWidget *parent = nullptr);
+    KDirListerTest(QWidget *parent = nullptr, const QUrl &url = {});
     ~KDirListerTest();
 
 public Q_SLOTS:
